| BS | R Documentation |
Computes the pdf, cdf, value at risk and expected shortfall for the Birnbaum-Saunders distribution due to Birnbaum and Saunders (1969a, 1969b) given by
\begin{array}{ll} &\displaystyle f(x) = \frac {x^{1/2} + x^{-1/2}}{2 γ x} φ ≤ft( \frac {x^{1/2} - x^{-1/2}}{γ} \right), \\ &\displaystyle F (x) = Φ ≤ft( \frac {x^{1/2} - x^{-1/2}}{γ} \right), \\ &\displaystyle {\rm VaR}_p (X) = \frac {1}{4} ≤ft\{ γ Φ^{-1} (p) + √{4 + γ^2 ≤ft[ Φ^{-1} (p) \right]^2} \right\}^2, \\ &\displaystyle {\rm ES}_p (X) = \frac {1}{4 p} \int_0^p ≤ft\{ γ Φ^{-1} (v) + √{4 + γ^2 ≤ft[ Φ^{-1} (v) \right]^2} \right\}^2 dv \end{array}
for x > 0, 0 < p < 1, and γ > 0, the scale parameter.
dBS(x, gamma=1, log=FALSE) pBS(x, gamma=1, log.p=FALSE, lower.tail=TRUE) varBS(p, gamma=1, log.p=FALSE, lower.tail=TRUE) esBS(p, gamma=1)
x |
scaler or vector of values at which the pdf or cdf needs to be computed |
p |
scaler or vector of values at which the value at risk or expected shortfall needs to be computed |
gamma |
the value of the scale parameter, must be positive, the default is 1 |
log |
if TRUE then log(pdf) are returned |
log.p |
if TRUE then log(cdf) are returned and quantiles are computed for exp(p) |
lower.tail |
if FALSE then 1-cdf are returned and quantiles are computed for 1-p |
An object of the same length as x, giving the pdf or cdf values computed at x or an object of the same length as p, giving the values at risk or expected shortfall computed at p.
Saralees Nadarajah
S. Nadarajah, S. Chan and E. Afuecheta, An R Package for value at risk and expected shortfall, submitted
x=runif(10,min=0,max=1) dBS(x) pBS(x) varBS(x) esBS(x)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.